.. image:: navarp/gui/icons/navarp.svg
   :height: 200
   :width: 200

============
NavARP
============


**Nav**\ igation tools for **A**\ ngle **R**\ esolved **P**\ hotoemission spectroscopy data, *i.e.* a **companion app** during ARPES data acquitision (as in beamtime) and set of **dedicated libs** helping to get high quality figures for publication.

**Documentation site**: `https://fbisti.gitlab.io/navarp <https://fbisti.gitlab.io/navarp>`_

**Author**: Federico Bisti (federico.bisti@univaq.it), for complete list see `AUTHORS.rst <AUTHORS.rst>`_

**License**: GPL

**Version Number**: 1.7.0

.. image:: images/intro.gif
   :width: 90%

Installation
============

For installation instructions and requirements, see `INSTALLATION.rst <INSTALLATION.rst>`_.


Update
=============

To update the NavARP project to the last version, see `UPDATE.rst <UPDATE.rst>`_.


Usage
=============

How to use the app and the related libs are explained in `USAGE.rst <USAGE.rst>`_.


Changelog
=============

For the list of changes along the releases, see `CHANGELOG.rst <CHANGELOG.rst>`_.


Contributing
=============

To contribute to the NavARP project, see `CONTRIBUTING.rst <CONTRIBUTING.rst>`_.
